@@ -1,4 +1,3 @@
-from __future__ import print_function
 from json import load
 from pulsar.managers.util.drmaa import DrmaaSessionFactory
 from pulsar.main import ArgumentParser
@@ -11,7 +10,7 @@ def main(argv=None):
     arg_parser = ArgumentParser(description=DESCRIPTION)
     arg_parser.add_argument("--job_attributes", required=True)
     args = arg_parser.parse_args(argv)
-    job_attributes = load(open(args.job_attributes, "r"))
+    job_attributes = load(open(args.job_attributes))
     session = DrmaaSessionFactory().get()
     external_id = session.run_job(**job_attributes)
     print(external_id)
